Changelog
==========

1.1.2 (2025-10-14)
------------------

- Add support for Python 3.14.

- Drop support for Python 3.7 and 3.8.


1.1.1 (2024-10-09)
------------------

- Add support for Python 3.12 and 3.13.


1.1.0 (2022-10-28)
------------------

- New command-line argument: ``--encode-text``.

- Add support for Python 3.11.

- Drop support for Python 3.6.


1.0.1 (2022-01-21)
------------------

- Don't fail with an ImportError when libzbar is not available on the system,
  but print a warning instead.

- New command-line argument: ``--decode``, enabled by default when libzbar is
  available on the system.


1.0.0 (2022-01-21)
------------------

- First public release.
